OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Pirmās palaišanas vednis",
    "Schedule work & meetings, synced with all your devices." : "Ieplāno darbu un sapulces, kas sinhronizētas ar visām jūsu ierīcēm.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Turiet savus kolēģus un draugus vienuviet, neizpludinot viņu privāto informāciju.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Vienkārša e-pasta lietotne labi apvienota ar Datnēm, Kontaktiem un Kalendāru.",
    "App recommendation: Tasks" : "Lietotnes ieteikums: Uzdevumi",
    "App recommendation: Forms" : "Lietotnes ieteikums: Veidlapas",
    "Access files via WebDAV" : "Piekļūt datnēm caur WebDAV",
    "Desktop client" : "Darbvirsmas klients",
    "iOS app" : "iOS lietotne",
    "About & What's new" : "Par un kas jauns",
    "Close" : "Aizvērt",
    "More about Nextcloud" : "Vairāk par Nextcloud",
    "Privacy" : "Privātums",
    "Host your data and files where you decide." : "Izvēlies, kur mitināt savus datus un datnes!",
    "Import and export anything you want with open standards." : "Ievieto un izgūsti jebko, ko vēlies, ar atvērtiem standartiem!",
    "Community" : "Kopiena",
    "Get the apps to sync your files" : "Saņem lietotnes, lai sinhronizētu savas datnes",
    "Server address" : "Servera adrese",
    "Read more" : "Lasīt vairāk",
    "Forms: automatically sync with a spreadsheet" : "Veidlapas: automātiski sinhronizēt ar izklājlapu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
